.. _api_dimse_provider:

.. py:module:: pynetdicom.dimse

Service Provider (:mod:`pynetdicom.dimse`)
===========================================

.. currentmodule:: pynetdicom.dimse

The DIMSE Service Provider provides methods for sending and receiving messages
to and from a peer AE.

.. autosummary::
   :toctree: generated/

   DIMSEServiceProvider
